@@ -305,7 +305,8 @@ void HeaderGenerator::writeTypeIndexDefineLine(QTextStream& s, const TypeEntry*
         const ComplexTypeEntry* cType = reinterpret_cast<const ComplexTypeEntry*>(typeEntry);
         if (cType->baseContainerType()) {
             const AbstractMetaClass* metaClass = classes().findClass(cType);
-            _writeTypeIndexDefineLine(s, getTypeIndexVariableName(metaClass, true), typeIndex);
+            if (metaClass->templateBaseClass())
+                _writeTypeIndexDefineLine(s, getTypeIndexVariableName(metaClass, true), typeIndex);
         }
     }
     if (typeEntry->isEnum()) {
@@ -421,7 +422,7 @@ void HeaderGenerator::finishGeneration()
         s << "#define protected public" << endl << endl;
     }
 
-    s << "#include <Python.h>" << endl;
+    s << "#include <sbkpython.h>" << endl;
     s << "#include <conversions.h>" << endl;
     s << "#include <sbkenum.h>" << endl;
     s << "#include <basewrapper.h>" << endl;
