@@ -864,7 +864,7 @@ bool ShibokenGenerator::isWrapperType(const AbstractMetaType* metaType)
 
 bool ShibokenGenerator::isPointerToWrapperType(const AbstractMetaType* type)
 {
-    return isObjectType(type) || type->isValuePointer();
+    return (isObjectType(type) && type->indirections() == 1) || type->isValuePointer();
 }
 
 bool ShibokenGenerator::shouldDereferenceArgumentPointer(const AbstractMetaArgument* arg)
@@ -903,11 +903,13 @@ QString ShibokenGenerator::cpythonCheckFunction(const AbstractMetaType* metaType
     if (isNumber(baseName))
         return genericNumberType ? QString("SbkNumber_Check") : QString("%1_Check").arg(baseName);
 
+
     baseName.clear();
     QTextStream b(&baseName);
     // exclude const on Objects
     Options flags = getConverterOptions(metaType);
     writeBaseConversion(b, metaType, 0, flags);
+
     return QString("%1checkType").arg(baseName);
 }
 
@@ -941,6 +943,9 @@ QString ShibokenGenerator::guessCPythonCheckFunction(const QString& type, Abstra
     if (type == "PyBuffer")
         return "Shiboken::Buffer::checkType";
 
+    if (type == "str")
+        return "Shiboken::String::check";
+
     *metaType = buildAbstractMetaTypeFromString(type);
     if (*metaType && !(*metaType)->typeEntry()->isCustom())
         return QString();
