@@ -21,7 +21,7 @@
  */
 
 #include "objectview.h"
-#include "objecttype.h"
+#include "objectmodel.h"
 #include "str.h"
 
 Str
@@ -40,3 +40,9 @@ ObjectView::modifyModelData(Str& data)
 }
 
 
+ObjectType*
+ObjectView::getRawModelData()
+{
+    return m_model->data();
+}
+
